@@ -29,6 +29,7 @@ def usage() -> str:
       lb view                  View images
 
       lb bigdirs               Discover folders which take much room
+      lb mv-list               Reach a target free space by moving data across mount points
       lb dedupe                Deduplicate local db files
 
       lb christen              Cleanse files by giving them a new name
@@ -120,6 +121,8 @@ def create_subcommands_parser():
 
     subp_bigdirs = add_parser(subparsers, "bigdirs", ["largefolders", "large_folders"])
     subp_bigdirs.set_defaults(func=scripts.bigdirs)
+    subp_move_list = add_parser(subparsers, "mv-list", ["movelist", "move-list", "move_list"])
+    subp_move_list.set_defaults(func=scripts.move_list)
     subp_dedupe = add_parser(subparsers, "dedupe")
     subp_dedupe.set_defaults(func=scripts.deduplicate_db)
     subp_christen = add_parser(subparsers, "christen")
