@@ -4,6 +4,7 @@ from collections.abc import Iterable
 from datetime import datetime, timedelta, timezone
 from functools import wraps
 from pathlib import Path
+from random import shuffle
 from shutil import which
 from typing import Any, Dict, Generator, List, Optional, Union
 
@@ -292,36 +293,42 @@ def clean_path(p):
     path = Path(p)
     ext = path.suffix
     p = str(path.parent / path.stem)
-    p = (
-        p.replace("...", "…")
-        .replace("*", "")
-        .replace("&", "")
-        .replace("%", "")
-        .replace("$", "")
-        .replace("#", "")
-        .replace("@", "")
-        .replace("!", "")
-        .replace("^", "")
-        .replace("'", "")
-        .replace('"', "")
-        .replace(")", "")
-    )
-    p = replace_consecutives(p, chars=["-", "."])
-    p = (
-        p.replace("(", " ")
-        .replace("-.", ".")
-        .replace(" :", ":")
-        .replace(" - ", " ")
-        .replace("- ", " ")
-        .replace(" -", " ")
-        .replace(" _ ", "_")
-        .replace(" _", "_")
-        .replace("_ ", "_")
-    )
-    p = replace_folder_ending(p, [" ", "-", "_", "."])
-    p = replace_basename_prefixes(p, [" ", "-"])
-    p = remove_whitespaace(p)
-    p = re.sub(r"\.+$", "", p)
+
+    while True:
+        p1 = p
+        p = (
+            p.replace("...", "…")
+            .replace("*", "")
+            .replace("&", "")
+            .replace("%", "")
+            .replace("$", "")
+            .replace("#", "")
+            .replace("@", "")
+            .replace("!", "")
+            .replace("^", "")
+            .replace("'", "")
+            .replace('"', "")
+            .replace(")", "")
+        )
+        p = replace_consecutives(p, chars=["-", "."])
+        p = (
+            p.replace("(", " ")
+            .replace("-.", ".")
+            .replace(" :", ":")
+            .replace(" - ", " ")
+            .replace("- ", " ")
+            .replace(" -", " ")
+            .replace(" _ ", "_")
+            .replace(" _", "_")
+            .replace("_ ", "_")
+        )
+        p = replace_folder_ending(p, [" ", "-", "_", "."])
+        p = replace_basename_prefixes(p, [" ", "-"])
+        p = remove_whitespaace(p)
+        p = re.sub(r"\.+$", "", p)
+        if p1 == p:
+            break
+
     return p + ext
 
 
@@ -609,3 +616,32 @@ def clear_input():
         # Try to flush the buffer
         while msvcrt.kbhit():
             msvcrt.getch()
+
+
+def set_readline_completion(list_):
+    try:
+        import readline
+    except ModuleNotFoundError:
+        return "Windows not supported lolz"
+
+    def create_completer(list_):
+        def list_completer(_text, state):
+            line = readline.get_line_buffer()
+
+            if not line:
+                min_depth = min([s.count(os.sep) for s in list_]) + 1
+                result_list = [c + " " for c in list_ if c.count(os.sep) <= min_depth]
+                shuffle(result_list)
+                return result_list[:25][state]
+            else:
+                match_list = [s for s in list_ if s.startswith(line)]
+                min_depth = min([s.count(os.sep) for s in match_list]) + 1
+                result_list = [c + " " for c in match_list if c.count(os.sep) <= min_depth]
+                shuffle(result_list)
+                return result_list[:15][state]
+
+        return list_completer
+
+    readline.set_completer(create_completer(list_))
+    readline.set_completer_delims("\t")
+    readline.parse_and_bind("tab: complete")
